<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>Dodaj priključke</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Traži:</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="102"/>
        <source>Add Widget</source>
        <translation>Dodaj programčić</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="112"/>
        <source>Close</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(istovremeno se može pokrenuti samo jedan primjerak)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>Konfiguriraj ploču</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="39"/>
        <source>Placement</source>
        <translation>Mjesto</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="43"/>
        <source>Styling</source>
        <translation>Stiliziranje</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="47"/>
        <source>Widgets</source>
        <translation>Programčići</translation>
    </message>
</context>
<context>
    <name>ConfigPlacement</name>
    <message>
        <location filename="../config/configplacement.ui" line="20"/>
        <source>Configure Placement</source>
        <translation>Konfiguriraj mjesto</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="44"/>
        <source>Size</source>
        <translation>Veličina</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Negativna vrijednost piksela postavlja duljinu ploče na toliki broj piksela minus dostupnog prostora na ekranu.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;Npr. „Duljina” postavljena na −100 px, s veličinom ekrana od 1000 px, tada će stvarna duljina ploče biti 900 px.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="81"/>
        <source>Size:</source>
        <translation>Veličina:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="88"/>
        <source>Length:</source>
        <translation>Duljina:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="101"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="109"/>
        <location filename="../config/configplacement.ui" line="153"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="166"/>
        <source>Icon size:</source>
        <translation>Veličina ikone:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="173"/>
        <source>Rows:</source>
        <translation>Broj redaka:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>Poravnanje i položaj</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="208"/>
        <source>Alignment:</source>
        <translation>Poravnanje:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="219"/>
        <location filename="../config/configplacement.cpp" line="188"/>
        <source>Left</source>
        <translation>Lijevo</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="224"/>
        <location filename="../config/configplacement.cpp" line="189"/>
        <location filename="../config/configplacement.cpp" line="195"/>
        <source>Center</source>
        <translation>Centrirano</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="229"/>
        <location filename="../config/configplacement.cpp" line="190"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="237"/>
        <source>Position:</source>
        <translation>Položaj:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation>A&amp;utomatsko skrivanje</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="262"/>
        <location filename="../config/configplacement.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>Nula znači bez animacije</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>Trajanje animacije:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="288"/>
        <location filename="../config/configplacement.ui" line="314"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="301"/>
        <location filename="../config/configplacement.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation>Nula znači bez odgađanja</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="304"/>
        <source>Show with delay:</source>
        <translation>Prikaži s odgađanjem:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="327"/>
        <source>Visible thin margin for hidden panel</source>
        <translation>Vidljiva tanka margina za skrivene ploče</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="334"/>
        <source>Hide only on overlapping a window</source>
        <translation>Sakrij samo pri prekrivanju prozora</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="344"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation>Nemoj dopustiti da se maksimalno prošireni prozori povlače ispod prozora ploče</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="347"/>
        <source>Reserve space on display</source>
        <translation>Rezerviraj prostor na ekranu</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="154"/>
        <source>Top of screen</source>
        <translation>Gore na ekranu</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="155"/>
        <source>Left of screen</source>
        <translation>Lijevo na ekranu</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="156"/>
        <source>Right of screen</source>
        <translation>Desno na ekranu</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="157"/>
        <source>Bottom of screen</source>
        <translation>Dolje na ekranu</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="166"/>
        <source>Top of screen %1</source>
        <translation>Gore na ekranu %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="167"/>
        <source>Left of screen %1</source>
        <translation>Lijevo na ekranu %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="168"/>
        <source>Right of screen %1</source>
        <translation>Desno na ekranu %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="169"/>
        <source>Bottom of screen %1</source>
        <translation>Dolje na ekranu %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="194"/>
        <source>Top</source>
        <translation>Gore</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="196"/>
        <source>Bottom</source>
        <translation>Dolje</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>Konfiguriraj priključke</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>Napomena: promjene na ovoj stranici ne mogu se poništiti.</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>Premjesti prema gore</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="115"/>
        <location filename="../config/configpluginswidget.ui" line="129"/>
        <location filename="../config/configpluginswidget.ui" line="150"/>
        <location filename="../config/configpluginswidget.ui" line="164"/>
        <location filename="../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>Premjesti prema dolje</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>Ukloni</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Konfiguriraj</translation>
    </message>
</context>
<context>
    <name>ConfigStyling</name>
    <message>
        <location filename="../config/configstyling.ui" line="20"/>
        <source>Configure Styling</source>
        <translation>Konfiguriraj stiliziranje</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="44"/>
        <source>Custom styling</source>
        <translation>Prilagođeno stiliziranje</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="65"/>
        <source>Font color:</source>
        <translation>Boja fonta:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="105"/>
        <source>Background color:</source>
        <translation>Boja pozadine:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="144"/>
        <source>Background opacity:</source>
        <translation>Neprozirnost pozadine:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="176"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;Za prozirnost ploče, potrebno je sastavljanje slike i pozadine.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="204"/>
        <source>Background image:</source>
        <translation>Slika pozadine:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="256"/>
        <source>A partial workaround for widget styles that
cannot give a separate theme to the panel.

You might also want to disable:

LXQt Appearance Configuration →
Icons Theme →
Colorize icons based on widget style (palette)</source>
        <translation>Djelomična alternativa za stilove programčića
koji ploči ne mogu dati zasebnu temu.

Možda želiš deaktivirati i:

Konfiguracija LXQt izgleda →
Tema ikona →
Oboji ikone na osnovi stila programčića (paleta)</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="266"/>
        <source>Override icon &amp;theme</source>
        <translation>Nadjačaj &amp;temu ikona</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="281"/>
        <source>Icon theme for panels:</source>
        <translation>Tema ikona za ploče:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="189"/>
        <location filename="../config/configstyling.cpp" line="205"/>
        <source>Pick color</source>
        <translation>Odaberi boju</translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="223"/>
        <source>Pick image</source>
        <translation>Odaberi sliku</translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="223"/>
        <source>Images (*.png *.gif *.jpg *.svg)</source>
        <translation>Slike (*.png *.gif *.jpg *.svg)</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../lxqtpanel.cpp" line="1495"/>
        <location filename="../lxqtpanel.cpp" line="1521"/>
        <source>Panel</source>
        <translation>Ploča</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1524"/>
        <source>Configure Panel</source>
        <translation>Konfiguriraj ploču</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1529"/>
        <source>Manage Widgets</source>
        <translation>Upravljaj programčićima</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1535"/>
        <source>Add New Panel</source>
        <translation>Dodaj novu ploču</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1542"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation>Ukloni ploču</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1547"/>
        <source>Lock This Panel</source>
        <translation>Zaključaj ovu ploču</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1710"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation>Ukloni ploču</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1711"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>Uklanjanje ploče se ne može poništiti.
Svejedno ukloniti ovu ploču?</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../plugin.cpp" line="455"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>Konfiguriraj „%1”</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="460"/>
        <source>Move &quot;%1&quot;</source>
        <translation>Premjesti „%1”</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="468"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>Ukloni „%1”</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="340"/>
        <source>Use alternate configuration file.</source>
        <translation>Koristi alternativnu konfiguracijsku datoteku.</translation>
    </message>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="341"/>
        <source>Configuration file</source>
        <translation>Konfiguracijska datoteka</translation>
    </message>
</context>
</TS>
